/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "mgos.h"
#include "mgos_htu21df_internal.h"
#include "mgos_i2c.h"

// Datasheet:
// https://cdn-shop.adafruit.com/datasheets/1899_HTU21D.pdf

// Private functions follow
// Private functions end

// Public functions follow
struct mgos_htu21df *mgos_htu21df_create(struct mgos_i2c *i2c, uint8_t i2caddr) {
  struct mgos_htu21df *sensor;

  if (!i2c) return NULL;

  sensor=calloc(1, sizeof(struct mgos_htu21df));
  if (!sensor) return NULL;
  sensor->i2caddr=i2caddr;
  sensor->i2c=i2c;
  sensor->last_read_time=0;

  LOG(LL_INFO, ("HTU21DF created at I2C 0x%02x", i2caddr));
  return sensor;
}

void mgos_htu21df_destroy(struct mgos_htu21df **sensor) {
  if (!*sensor) return;
  free (*sensor);
  *sensor=NULL;
  return;
}

bool mgos_htu21df_read(struct mgos_htu21df *sensor) {
  double now = mg_time();

  if (!sensor || !sensor->i2c)
    return false;

  if (now - sensor->last_read_time < MGOS_HTU21DF_READ_DELAY) {
    return true;
  }
  // Read out sensor data here 
  //
 
  LOG(LL_DEBUG, ("temperature=%.2fC humidity=%.1f%%", sensor->temperature, sensor->humidity));
  sensor->last_read_time=now;
  return true;
}

float mgos_htu21df_getTemperature(struct mgos_htu21df *sensor) {
  if (!mgos_htu21df_read(sensor)) return NAN;

  return sensor->temperature;
}

float mgos_htu21df_getHumidity(struct mgos_htu21df *sensor) {
  if (!mgos_htu21df_read(sensor)) return NAN;

  return sensor->humidity;
}

bool mgos_htu21df_i2c_init(void) {
  return true;
}
// Public functions end
